"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = exports.WS = void 0;

var _utils = require("../utils");

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/** Whitespace modifiers to be used with add() method */
var WS;
/**
 * API for constructing SQL string (especially the whitespace part).
 *
 * It hides the internal implementation.
 * Originally it used plain string concatenation, which was expensive.
 * Now it's storing items to array and builds the string only in the end.
 */

exports.WS = WS;

(function (WS) {
  WS[WS["SPACE"] = 1] = "SPACE";
  WS[WS["NO_SPACE"] = 2] = "NO_SPACE";
  WS[WS["NEWLINE"] = 3] = "NEWLINE";
  WS[WS["NO_NEWLINE"] = 4] = "NO_NEWLINE";
  WS[WS["INDENT"] = 5] = "INDENT";
  WS[WS["SINGLE_INDENT"] = 6] = "SINGLE_INDENT";
})(WS || (exports.WS = WS = {}));

var WhitespaceBuilder = /*#__PURE__*/function () {
  function WhitespaceBuilder(indentation) {
    _classCallCheck(this, WhitespaceBuilder);

    this.indentation = indentation;

    _defineProperty(this, "query", []);
  }
  /**
   * Appends token strings and whitespace modifications to SQL string.
   */


  _createClass(WhitespaceBuilder, [{
    key: "add",
    value: function add() {
      for (var _len = arguments.length, items = new Array(_len), _key = 0; _key < _len; _key++) {
        items[_key] = arguments[_key];
      }

      for (var _i = 0, _items = items; _i < _items.length; _i++) {
        var item = _items[_i];

        switch (item) {
          case WS.SPACE:
            this.query.push(WS.SPACE);
            break;

          case WS.NO_SPACE:
            this.trimHorizontalWhitespace();
            break;

          case WS.NEWLINE:
            this.trimHorizontalWhitespace();
            this.addNewline();
            break;

          case WS.NO_NEWLINE:
            this.trimAllWhitespace();
            break;

          case WS.INDENT:
            for (var i = 0; i < this.indentation.getLevel(); i++) {
              this.query.push(WS.SINGLE_INDENT);
            }

            break;

          case WS.SINGLE_INDENT:
            this.query.push(WS.SINGLE_INDENT);
            break;

          default:
            this.query.push(item);
        }
      }
    }
  }, {
    key: "trimHorizontalWhitespace",
    value: function trimHorizontalWhitespace() {
      while (isHorizontalWhitespace((0, _utils.last)(this.query))) {
        this.query.pop();
      }
    }
  }, {
    key: "trimAllWhitespace",
    value: function trimAllWhitespace() {
      while (isWhitespace((0, _utils.last)(this.query))) {
        this.query.pop();
      }
    }
  }, {
    key: "addNewline",
    value: function addNewline() {
      if (this.query.length > 0 && (0, _utils.last)(this.query) !== WS.NEWLINE) {
        this.query.push(WS.NEWLINE);
      }
    }
    /**
     * Returns the final SQL string.
     */

  }, {
    key: "toString",
    value: function toString() {
      var _this = this;

      return this.query.map(function (item) {
        return _this.itemToString(item);
      }).join('');
    }
  }, {
    key: "itemToString",
    value: function itemToString(item) {
      switch (item) {
        case WS.SPACE:
          return ' ';

        case WS.NEWLINE:
          return '\n';

        case WS.SINGLE_INDENT:
          return this.indentation.getSingleIndent();

        default:
          return item;
      }
    }
  }]);

  return WhitespaceBuilder;
}();

exports["default"] = WhitespaceBuilder;

var isHorizontalWhitespace = function isHorizontalWhitespace(item) {
  return item === WS.SPACE || item === WS.SINGLE_INDENT;
};

var isWhitespace = function isWhitespace(item) {
  return item === WS.SPACE || item === WS.SINGLE_INDENT || item === WS.NEWLINE;
};
//# sourceMappingURL=WhitespaceBuilder.js.map