import Indentation from './Indentation';
/** Whitespace modifiers to be used with add() method */
export declare enum WS {
    SPACE = 1,
    NO_SPACE = 2,
    NEWLINE = 3,
    NO_NEWLINE = 4,
    INDENT = 5,
    SINGLE_INDENT = 6
}
/**
 * API for constructing SQL string (especially the whitespace part).
 *
 * It hides the internal implementation.
 * Originally it used plain string concatenation, which was expensive.
 * Now it's storing items to array and builds the string only in the end.
 */
export default class WhitespaceBuilder {
    private indentation;
    private query;
    constructor(indentation: Indentation);
    /**
     * Appends token strings and whitespace modifications to SQL string.
     */
    add(...items: (WS | string)[]): void;
    private trimHorizontalWhitespace;
    private trimAllWhitespace;
    private addNewline;
    /**
     * Returns the final SQL string.
     */
    toString(): string;
    private itemToString;
}
